import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;

/**
 * <P>
 * This class demonstrates how to use the Goolgle Maps API with java. Google
 * Maps is based on Javascript which is similar to, but not the same as, Java.
 * This class writes an html file to disk and then launches an external web
 * browser to view the map.
 * </P>
 * <P>
 * This code is based on an example from the Google Maps website:<br>
 * http://code.google.com/apis/maps/documentation/examples/map-markers.html
 * </P>
 * 
 * @author Mark Woehrer
 * @version 1a3
 */

public class Driver {

	/**
	 * The content is stored in a template containing placeholders for the
	 * various points of interest (and the zoom factor). A simple search and
	 * replace operation is performed replacing each placeholder with the
	 * appropriate javascript.
	 */

	private String content;

	public Driver() throws IOException {
		super();

		/*
		 * The content contains four placeholders for the center point, zoom
		 * level, and the data array. The placeholders are the names
		 * surrounded by underscores. For example, the placeholder for the
		 * center point is _center_point_.
		 * 
		 * Other map attributes may be changed by directly modifying the
		 * template. For example, to remove the zoom control simply remove the
		 * line containing the addControl() method.
		 */

		content = "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Strict//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd'>\n"
				+ "<html xmlns='http://www.w3.org/1999/xhtml' xmlns:v='urn:schemas-microsoft-com:vml'>\n"
				+ "	<head>\n"
				+ "		<meta http-equiv='content-type' content='text/html; charset=utf-8'/>\n"
				+ "		<title>Google Maps JavaScript API Example</title>\n"
				+ "		<script src='http://maps.google.com/maps?file=api&amp;v=2' type='text/javascript'></script>\n"
				+ "		<script type='text/javascript'>\n"
				+ "		function initialize() {\n"
				+ "			if (GBrowserIsCompatible()) {\n"
				+ "				var map = new GMap2(document.getElementById('map_canvas'));\n"
				+ "				var center_point = new GLatLng(_center_point_);\n"
				+ "				map.setCenter(center_point, _zoom_level_);\n"

				+ "				var myArray = _data_array_;\n"
				+ "				for (index in myArray)\n"
				+ "				{\n"
		 		+ "					var point = myArray[index]\n"
		 		+ "					map.addOverlay(new GMarker(point));\n"
		 		+ "				}\n"
				
				+ "				map.addControl(new GLargeMapControl());\n"
				+ "			}\n"
				+ "		}\n"
				+ "		</script>\n"
				+ "	</head>\n"
				+ "	<body onload='initialize()' onunload='GUnload()'>\n"
				+ "		<div id='map_canvas' style='width: 500px; height: 300px'></div>\n"
				+ "		<div id='message'></div>\n" + "	</body>\n" + "</html>";

		/*
		 * The following code replaces each of the placeholders in the content
		 * string with the appropriate Javascript. Notice that the Javascript is
		 * generated using the toString() method from each Java object
		 */

		// Set the center point
		LatLng center_point = new LatLng(38.959902, -95.253199);
		content = content.replaceAll("_center_point_", center_point.toString());

		// Set the zoom level
		int zoom = 3;
		content = content.replaceAll("_zoom_level_", Integer.toString(zoom));

		// Set the zip point
		LatLng point = new LatLng(31.030819, -91.07576);
		content = content.replaceAll("_point_", point.toString());

		Database database = new Database();
		database.add(new Zip(73019, "Norman", "OK", new LatLng(35.221617, -97.418236)));
		database.add(new Zip(68066, "Wahoo", "NE", new LatLng(41.213292, -96.619044)));

		
		content = content.replaceAll("_data_array_", database.toGoogleString());

		// Save to disk
		BufferedWriter writer = new BufferedWriter(new FileWriter("out.html"));
		writer.write(content);
		writer.flush();

		// Open in external browser
		Runtime.getRuntime().exec("open out.html"); // Mac
        //Runtime.getRuntime().exec("firefox out.html"); // UNIX/Linux
		//Runtime.getRuntime().exec("C:/Program Files/Mozilla Firefox/firefox.exe out.html"); // Windows

	}

	/**
	 * @param args
	 * @throws IOException
	 */
	public static void main(String[] args) throws IOException {
		// TODO Auto-generated method stub

		@SuppressWarnings("unused")
		Driver driver = new Driver();

	}

}